@@ -7,7 +7,7 @@ if TYPE_CHECKING:
 
 
 class MinimalProfile(Profile):
-	def __init__(self):
+	def __init__(self) -> None:
 		super().__init__(
 			'Minimal',
 			ProfileType.Minimal,
