@@ -10,6 +10,7 @@ from ..translationhandler import TranslationHandler, Language
 if TYPE_CHECKING:
 	_: Any
 
+
 class Selector:
 	def __init__(
 		self,
@@ -68,42 +69,19 @@ class Selector:
 		:param no_store: A boolean which determines that the field should or shouldn't be stored in the data storage
 		:type no_store: bool
 		"""
-		self._description = description
-		self.func = func
 		self._display_func = display_func
-		self._current_selection = default
-		self.enabled = enabled
-		self._dependencies = dependencies
-		self._dependencies_not = dependencies_not
-		self.exec_func = exec_func
-		self._preview_func = preview_func
-		self.mandatory = mandatory
 		self._no_store = no_store
-		self._default = default
 
-	@property
-	def default(self) -> Any:
-		return self._default
-
-	@property
-	def description(self) -> str:
-		return self._description
-
-	@property
-	def dependencies(self) -> List:
-		return self._dependencies
-
-	@property
-	def dependencies_not(self) -> List:
-		return self._dependencies_not
-
-	@property
-	def current_selection(self) -> Optional[Any]:
-		return self._current_selection
-
-	@property
-	def preview_func(self):
-		return self._preview_func
+		self.description = description
+		self.func = func
+		self.current_selection = default
+		self.enabled = enabled
+		self.dependencies = dependencies
+		self.dependencies_not = dependencies_not
+		self.exec_func = exec_func
+		self.preview_func = preview_func
+		self.mandatory = mandatory
+		self.default = default
 
 	def do_store(self) -> bool:
 		return self._no_store is False
@@ -112,45 +90,45 @@ class Selector:
 		self.enabled = status
 
 	def update_description(self, description: str):
-		self._description = description
+		self.description = description
 
 	def menu_text(self, padding: int = 0) -> str:
-		if self._description == '':  # special menu option for __separator__
+		if self.description == '':  # special menu option for __separator__
 			return ''
 
 		current = ''
 
 		if self._display_func:
-			current = self._display_func(self._current_selection)
+			current = self._display_func(self.current_selection)
 		else:
-			if self._current_selection is not None:
-				current = str(self._current_selection)
+			if self.current_selection is not None:
+				current = str(self.current_selection)
 
 		if current:
 			padding += 5
-			description = unicode_ljust(str(self._description), padding, ' ')
+			description = unicode_ljust(str(self.description), padding, ' ')
 			current = current
 		else:
-			description = self._description
+			description = self.description
 			current = ''
 
 		return f'{description} {current}'
 
 	def set_current_selection(self, current: Optional[Any]):
-		self._current_selection = current
+		self.current_selection = current
 
 	def has_selection(self) -> bool:
-		if not self._current_selection:
+		if not self.current_selection:
 			return False
 		return True
 
 	def get_selection(self) -> Any:
-		return self._current_selection
+		return self.current_selection
 
 	def is_empty(self) -> bool:
-		if self._current_selection is None:
+		if self.current_selection is None:
 			return True
-		elif isinstance(self._current_selection, (str, list, dict)) and len(self._current_selection) == 0:
+		elif isinstance(self.current_selection, (str, list, dict)) and len(self.current_selection) == 0:
 			return True
 		return False
 
@@ -197,6 +175,8 @@ class AbstractMenu:
 		self._sync_all()
 		self._populate_default_values()
 
+		self.defined_text = str(_('Defined'))
+
 	@property
 	def last_choice(self):
 		return self._last_choice
@@ -382,9 +362,10 @@ class AbstractMenu:
 		result = None
 
 		if selector.func is not None:
-			presel_val = self.option(config_name).get_selection()
-			result = selector.func(presel_val)
+			cur_value = self.option(config_name).get_selection()
+			result = selector.func(cur_value)
 			self._menu_options[config_name].set_current_selection(result)
+
 			if selector.do_store():
 				self._data_store[config_name] = result
 
@@ -398,19 +379,23 @@ class AbstractMenu:
 		return True
 
 	def _verify_selection_enabled(self, selection_name: str) -> bool:
-		""" general """
 		if selection := self._menu_options.get(selection_name, None):
 			if not selection.enabled:
 				return False
 
 			if len(selection.dependencies) > 0:
-				for d in selection.dependencies:
-					if not self._verify_selection_enabled(d) or self._menu_options[d].is_empty():
-						return False
+				for dep in selection.dependencies:
+					if isinstance(dep, str):
+						if not self._verify_selection_enabled(dep) or self._menu_options[dep].is_empty():
+							return False
+					elif callable(dep):  # callable dependency eval
+						return dep()
+					else:
+						raise ValueError(f'Unsupported dependency: {selection_name}')
 
 			if len(selection.dependencies_not) > 0:
-				for d in selection.dependencies_not:
-					if not self._menu_options[d].is_empty():
+				for dep in selection.dependencies_not:
+					if not self._menu_options[dep].is_empty():
 						return False
 			return True
 
@@ -454,8 +439,8 @@ class AbstractMenu:
 
 
 class AbstractSubMenu(AbstractMenu):
-	def __init__(self, data_store: Dict[str, Any] = {}):
-		super().__init__(data_store=data_store)
+	def __init__(self, data_store: Dict[str, Any] = {}, preview_size: float = 0.2):
+		super().__init__(data_store=data_store, preview_size=preview_size)
 
 		self._menu_options['__separator__'] = Selector('')
 		self._menu_options['back'] = \
